package com.bonus.canteen.core.health.service;

import java.util.List;
import com.bonus.canteen.core.health.domain.HealthMedicalReportTemplate;

/**
 * 体检报告模板Service接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface IHealthMedicalReportTemplateService {
    /**
     * 查询体检报告模板
     * 
     * @param id 体检报告模板主键
     * @return 体检报告模板
     */
    public HealthMedicalReportTemplate selectHealthMedicalReportTemplateById(Long id);

    /**
     * 查询体检报告模板列表
     * 
     * @param healthMedicalReportTemplate 体检报告模板
     * @return 体检报告模板集合
     */
    public List<HealthMedicalReportTemplate> selectHealthMedicalReportTemplateList(HealthMedicalReportTemplate healthMedicalReportTemplate);

    /**
     * 新增体检报告模板
     * 
     * @param healthMedicalReportTemplate 体检报告模板
     * @return 结果
     */
    public int insertHealthMedicalReportTemplate(HealthMedicalReportTemplate healthMedicalReportTemplate);

    /**
     * 修改体检报告模板
     * 
     * @param healthMedicalReportTemplate 体检报告模板
     * @return 结果
     */
    public int updateHealthMedicalReportTemplate(HealthMedicalReportTemplate healthMedicalReportTemplate);

    /**
     * 批量删除体检报告模板
     * 
     * @param ids 需要删除的体检报告模板主键集合
     * @return 结果
     */
    public int deleteHealthMedicalReportTemplateByIds(Long[] ids);

    /**
     * 删除体检报告模板信息
     * 
     * @param id 体检报告模板主键
     * @return 结果
     */
    public int deleteHealthMedicalReportTemplateById(Long id);
}
