package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthMedicalReportTemplate;
import com.bonus.canteen.core.health.service.IHealthMedicalReportTemplateService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 体检报告模板Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "体检报告模板接口")
@RestController
@RequestMapping("/health_medical_report_template")
public class HealthMedicalReportTemplateController extends BaseController {
    @Autowired
    private IHealthMedicalReportTemplateService healthMedicalReportTemplateService;

    /**
     * 查询体检报告模板列表
     */
    @ApiOperation(value = "查询体检报告模板列表")
    //@RequiresPermissions("health:template:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthMedicalReportTemplate healthMedicalReportTemplate) {
        startPage();
        List<HealthMedicalReportTemplate> list = healthMedicalReportTemplateService.selectHealthMedicalReportTemplateList(healthMedicalReportTemplate);
        return getDataTable(list);
    }

    /**
     * 导出体检报告模板列表
     */
    @ApiOperation(value = "导出体检报告模板列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:template:export")
    @SysLog(title = "体检报告模板", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出体检报告模板")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthMedicalReportTemplate healthMedicalReportTemplate) {
        List<HealthMedicalReportTemplate> list = healthMedicalReportTemplateService.selectHealthMedicalReportTemplateList(healthMedicalReportTemplate);
        ExcelUtil<HealthMedicalReportTemplate> util = new ExcelUtil<HealthMedicalReportTemplate>(HealthMedicalReportTemplate.class);
        util.exportExcel(response, list, "体检报告模板数据");
    }

    /**
     * 获取体检报告模板详细信息
     */
    @ApiOperation(value = "获取体检报告模板详细信息")
    //@RequiresPermissions("health:template:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthMedicalReportTemplateService.selectHealthMedicalReportTemplateById(id));
    }

    /**
     * 新增体检报告模板
     */
    @ApiOperation(value = "新增体检报告模板")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:template:add")
    @SysLog(title = "体检报告模板", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增体检报告模板")
    @PostMapping
    public AjaxResult add(@RequestBody HealthMedicalReportTemplate healthMedicalReportTemplate) {
        try {
            return toAjax(healthMedicalReportTemplateService.insertHealthMedicalReportTemplate(healthMedicalReportTemplate));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改体检报告模板
     */
    @ApiOperation(value = "修改体检报告模板")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:template:edit")
    @SysLog(title = "体检报告模板", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改体检报告模板")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthMedicalReportTemplate healthMedicalReportTemplate) {
        try {
            return toAjax(healthMedicalReportTemplateService.updateHealthMedicalReportTemplate(healthMedicalReportTemplate));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除体检报告模板
     */
    @ApiOperation(value = "删除体检报告模板")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:template:remove")
    @SysLog(title = "体检报告模板", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除体检报告模板")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthMedicalReportTemplateService.deleteHealthMedicalReportTemplateByIds(ids));
    }
}
